### Conversa com múltiplos LLMs
Aqui pode experimentar múltiplos LLMs sem um prompt de sistema.
As mensagens que pode ver no ecrã são aquelas enviadas para os LLMs
(com uma pequena variação onde apenas os primeiros 512 caracteres da resposta do LLM são enviados para o LLM).
